CORE DEVELOPERS
===============

* Chris Glass (chrisglass)
* Martin Brochhaus

CONTRIBUTORS
============

* Adrien Lemaire
* airtonix
* Aleš Kocjančič
* Anders Petersson
* Andrés Reyes Monge
* Audrey Roy
* Ben Lopatin
* Benjamin Wohlwend
* Bojan Mihelac
* Chris Morgan
* fivethreeo
* German Larrain
* ikresoft
* Issac Kelly
* Jacek Mitręga
* Jacob Rief
* Jonas Obrist
* Justin Steward 
* Kristian Øllegaard
* Martin Ogden
* Mike Yumatov
* Pavel Zhukov
* Per Rosengren
* Raúl Cumplido
* Rolo Mawlabaux
* Simon Luijk
* Sławomir Ehlert
* Stephen Muss
* Thomas Woolford

TRANSLATORS
===========

* Mikhail Kolesnik (Russian)
* Pavel Zhukov (Russian)
* Pedro Gracia (Spanish)
* Arturo Fernandez (Spanish)
